export declare enum MenuTarget {
    blank = "_blank",
    iframe = "iframe",
    tab = "tab"
}
export interface IHasChildren<T> {
    children?: T[];
}
export interface ICreateMenuPayload {
    id?: string;
    title: string;
    path: string;
    icon: string;
    hideSider?: boolean;
    auth?: string[];
    target: MenuTarget;
    parentId?: string;
}
export interface IHeaderMenu {
    id?: string;
    isDefault?: boolean;
    title: string;
    name: string;
    path?: string;
    icon?: string;
    /**
     * 自定义图标
     */
    custom?: string;
    hideSider?: boolean;
    auth?: string[];
    $secured?: string;
    target?: MenuTarget;
}
export interface IMenuInfo extends IHasChildren<IMenuInfo> {
    id?: string;
    title: string;
    header?: string;
    path?: string;
    icon?: string;
    /**
     * 自定义图标
     */
    custom?: string;
    auth?: string[];
    $secured?: string;
    target?: MenuTarget;
}
export interface IMoveMenuPayload {
    parentId: string;
    frontId: string;
}
export interface IUpdateMenuPayload {
    title: string;
    path: string;
    icon: string;
    hideSider?: boolean;
    auth?: string[];
    target: MenuTarget;
}
export interface IMaterial {
    id: string;
    name: string;
    length: number;
    format: string;
    lastModified: number;
    packageName: string;
}
export declare enum FieldType {
    int = "int",
    long = "long",
    BIT = "BIT",
    TINYINT = "TINYINT",
    SMALLINT = "SMALLINT",
    INTEGER = "INTEGER",
    BIGINT = "BIGINT",
    FLOAT = "FLOAT",
    REAL = "REAL",
    DOUBLE = "DOUBLE",
    NUMERIC = "NUMERIC",
    DECIMAL = "DECIMAL",
    CHAR = "CHAR",
    VARCHAR = "VARCHAR",
    LONGVARCHAR = "LONGVARCHAR",
    DATE = "DATE",
    TIME = "TIME",
    TIMESTAMP = "TIMESTAMP",
    BINARY = "BINARY",
    VARBINARY = "VARBINARY",
    LONGVARBINARY = "LONGVARBINARY",
    NULL = "NULL",
    OTHER = "OTHER",
    JAVA_OBJECT = "JAVA_OBJECT",
    DISTINCT = "DISTINCT",
    ARRAY = "ARRAY",
    BLOB = "BLOB",
    CLOB = "CLOB",
    DATALINK = "DATALINK",
    BOOLEAN = "BOOLEAN",
    NCHAR = "NCHAR",
    NVARCHAR = "NVARCHAR",
    LONGNVARCHAR = "LONGNVARCHAR",
    NCLOB = "NCLOB",
    SQLXML = "SQLXML",
    TIME_WITH_TIMEZONE = "TIME_WITH_TIMEZONE",
    TIMESTAMP_WITH_TIMEZONE = "TIMESTAMP_WITH_TIMEZONE"
}
export declare enum FieldDataType {
    string = "string",
    number = "number",
    integer = "integer",
    boolean = "boolean",
    array = "array",
    object = "object"
}
export declare const fieldTypeToDataTypeMapping: Record<FieldType, FieldDataType | undefined>;
export declare enum FieldInputType {
    Input = "Input",
    Password = "Password",
    Select = "Select",
    MultiSelect = "MultiSelect",
    Checkbox = "Checkbox",
    Radiobox = "Radiobox",
    EmailInput = "EmailInput",
    LinkInput = "LinkInput",
    TelInput = "TelInput",
    NumberInput = "NumberInput",
    Textarea = "Textarea",
    DatetimeInput = "DatetimeInput",
    DateInput = "DateInput",
    TimeInput = "TimeInput"
}
export declare const fieldTypeToInputTypeMapping: Record<FieldType, FieldInputType | undefined>;
export interface IField {
    name: string;
    title?: string;
    description?: string;
    type?: FieldType;
    dataType?: FieldDataType;
    primaryKey?: boolean;
    nullable?: boolean;
    autoIncrement?: boolean;
    idGenerator?: string;
    length?: number;
    precision?: number;
    scale?: number;
    insertable?: boolean;
    updatable?: boolean;
    writable?: boolean;
    sortable?: boolean;
    filterable?: boolean;
    searchable?: boolean;
    dynamic?: boolean;
    defaultValue?: any;
    updateValue?: any;
    dict?: string;
    domain?: string;
    columnName?: string;
    columnDefault?: any;
    annotations?: Record<string, any>;
    order?: number;
    inputType?: FieldInputType;
}
export interface IModelField {
    name: string;
    title?: string;
    description?: string;
    type: FieldDataType;
    required?: boolean;
    maxLength?: number;
    minLength?: number;
}
export declare enum RelationType {
    MANY_TO_ONE = "MANY_TO_ONE",
    MANY_TO_MANY = "MANY_TO_MANY",
    ONE_TO_ONE = "ONE_TO_ONE",
    ONE_TO_MANY = "ONE_TO_MANY"
}
export declare const relationTypes: RelationType[];
export declare const RelationTypeText: {
    MANY_TO_ONE: string;
    MANY_TO_MANY: string;
    ONE_TO_ONE: string;
    ONE_TO_MANY: string;
};
export interface IJoinField {
    local: string;
    target: string;
}
export interface IRelation {
    name: string;
    title?: string;
    description?: string;
    type: RelationType;
    sourceEntity?: string;
    targetEntity?: string;
    joinEntity?: string;
    joinFields?: IJoinField[];
    optional?: boolean;
    expandable?: boolean;
    generateForeignKey?: boolean;
    foreignKeyName?: string;
}
export declare enum OrderDirection {
    ASC = "ASC",
    DESC = "DESC"
}
export interface IIndexField {
    name: string;
    order: OrderDirection;
}
export interface IIndex {
    name: string;
    title?: string;
    description?: string;
    unique: boolean;
    fields?: IIndexField[];
}
export declare enum EntityEventType {
    preCreate = "preCreate",
    postCreate = "postCreate",
    preUpdate = "preUpdate",
    postUpdate = "postUpdate",
    preDelete = "preDelete",
    postDelete = "postDelete"
}
export declare const EntityEventTypeLabel: Record<keyof typeof EntityEventType, string>;
export interface ICallback {
    _event?: string;
    enabled?: boolean;
    trans?: boolean;
    fn?: string;
}
export interface IEntity {
    name: string;
    title: string;
    description: string;
    tableName: string;
    schema?: string;
    datasource?: string;
    className?: string;
    source?: string;
    multiTenant?: {
        enabled?: boolean;
        field?: string;
    };
    softDelete?: {
        enabled?: boolean;
        field?: string;
    };
    dynamic?: boolean;
    fields: Record<string, IField>;
    relations: Record<string, IRelation>;
    indexes: Record<string, IIndex>;
    onEvents: Record<string, ICallback[]>;
}
export interface IModel {
    name: string;
    title: string;
    description: string;
    properties: Record<string, IModelField>;
}
export interface IActionDef {
    title: string;
    desc: string;
    code: string;
    originalCode?: string;
    type: 'CREATE' | 'READ' | 'UPDATE' | 'DELETE';
}
export interface IDataItemDef {
    title: string;
    desc: string;
    value: any;
}
export interface IDataScopeDef {
    title: string;
    desc: string;
    rules: Record<string, any>;
    items: IDataItemDef[];
    system: boolean;
}
export interface IAuthorityDef {
    title: string;
    desc: string;
    code: string;
    originalCode?: string;
    type: 'SCOPE' | 'RESOURCE';
    children: IAuthorityDef[];
    actions: IActionDef[] | string[];
    dataScopes: IDataScopeDef[];
}
export interface IAuthorityPack {
    title: string;
    desc: string;
    code: string;
    authorities?: IAuthorityDef[];
    actions?: Record<string, IActionDef>;
    dataScopes?: IDataScopeDef[];
}
export interface ITable {
    name: string;
    entity: string;
    title?: string;
    remarks?: string;
    generateAuthority?: boolean;
    exists?: boolean;
    selected?: boolean;
}
export interface IDatabase {
    datasource?: string;
    name: string;
    tables?: ITable[];
}
export interface IDatasource {
    title?: string;
    name: string;
    version?: string;
    type?: string;
    databases: IDatabase[];
    defaultDatabase?: string;
}
export interface IDatasourceConfig {
    defaultDatasource: string;
    datasources: IDatasource[];
}
export interface IMicroApp {
    name: string;
    configUrl?: string;
    serviceUrl?: string;
    optionSetUrl?: string;
    baseUrl?: string;
}
